@@ -37,6 +37,12 @@ class CreateJobTemplateRequest(RpcRequest):
 	def set_StderrRedirectPath(self,StderrRedirectPath):
 		self.add_query_param('StderrRedirectPath',StderrRedirectPath)
 
+	def get_ClockTime(self):
+		return self.get_query_params().get('ClockTime')
+
+	def set_ClockTime(self,ClockTime):
+		self.add_query_param('ClockTime',ClockTime)
+
 	def get_CommandLine(self):
 		return self.get_query_params().get('CommandLine')
 
@@ -55,6 +61,12 @@ class CreateJobTemplateRequest(RpcRequest):
 	def set_PackagePath(self,PackagePath):
 		self.add_query_param('PackagePath',PackagePath)
 
+	def get_Mem(self):
+		return self.get_query_params().get('Mem')
+
+	def set_Mem(self,Mem):
+		self.add_query_param('Mem',Mem)
+
 	def get_StdoutRedirectPath(self):
 		return self.get_query_params().get('StdoutRedirectPath')
 
@@ -79,14 +91,44 @@ class CreateJobTemplateRequest(RpcRequest):
 	def set_ReRunable(self,ReRunable):
 		self.add_query_param('ReRunable',ReRunable)
 
+	def get_Thread(self):
+		return self.get_query_params().get('Thread')
+
+	def set_Thread(self,Thread):
+		self.add_query_param('Thread',Thread)
+
 	def get_Priority(self):
 		return self.get_query_params().get('Priority')
 
 	def set_Priority(self,Priority):
 		self.add_query_param('Priority',Priority)
 
+	def get_Gpu(self):
+		return self.get_query_params().get('Gpu')
+
+	def set_Gpu(self,Gpu):
+		self.add_query_param('Gpu',Gpu)
+
+	def get_Node(self):
+		return self.get_query_params().get('Node')
+
+	def set_Node(self,Node):
+		self.add_query_param('Node',Node)
+
+	def get_Task(self):
+		return self.get_query_params().get('Task')
+
+	def set_Task(self,Task):
+		self.add_query_param('Task',Task)
+
 	def get_Name(self):
 		return self.get_query_params().get('Name')
 
 	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+		self.add_query_param('Name',Name)
+
+	def get_Queue(self):
+		return self.get_query_params().get('Queue')
+
+	def set_Queue(self,Queue):
+		self.add_query_param('Queue',Queue)
\ No newline at end of file
