@@ -73,10 +73,10 @@ class GetCloudMetricLogsRequest(RpcRequest):
 	def set_MetricCategories(self,MetricCategories):
 		self.add_query_param('MetricCategories',MetricCategories)
 
-	def get__From(self):
+	def get_From(self):
 		return self.get_query_params().get('From')
 
-	def set__From(self,_From):
+	def set_From(self,_From):
 		self.add_query_param('From',_From)
 
 	def get_To(self):
